
# agnesi.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Witch_of_Agnesi
# https://mathworld.wolfram.com/WitchofAgnesi.html
           # includes animation
'''
  The animation linked to above does not specify how the 
  horizontal line between the Agnesi circle and vertical 
  moving line is defined. 

  I use a coupler connected to the Agnesi circle
  and another ball which are geared to rotate up and down. 
'''

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Witch of Agnesi")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)

a = 50
coordA = coord0 + Vec2d(-300, 0)
coordB = coord0 + Vec2d(300, 0)
coordC = coord0 + Vec2d(0,-a)
coordT = coordC + Vec2d(300, 0)
coordE = coord0 + Vec2d(-2*a,0)
coordF = coord0 + Vec2d(-200, -200)

pt0 = staticBall(space, "", coord0)
ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
beamAB = beam(space, ptA, ptB)  # represents the floor

ptC = staticBall(space, "C", coordC)
ptT = staticBall(space, "T", coordT)

_, ballV, ballU = coupler(space, ptC, ptT, a, Vec2d(-a, 0))
'''
 the wheels supporting the beam are geared so that it moves
 up and down and stays horizontal. The beam's end points 
 are ballV and ballU.
 
  ballV is the Agnesi circle, and ballU is to its right.
'''
'''
  create a long beamWU which uses ballU.
  It represents the  horizontal line between the 
  Agnesi circle and vertical moving line.
'''
coordW = coordC + Vec2d(-300, 0)
ballW = ball(space, "W", coordW)
beamWU = beam(space, ballW, ballU, color=MUSTARD)
pin(space, beamWU, ballV, (300-a,0))

# beamWU is grooved to hold ballP (for drawing)
coordP = (coordE.x, ballV.position.y)
ballP = ball(space, "P", coordP, color=RED)
groove(space, beamWU, ballP)

ballE = ball(space, "", coordE)
tb, ballUp, ballL, ballR = \
     tBeam(space, ballE, 0.5*a, -2*a, color=TANGERINE)
  # the trunk of the t-beam points up;
  # the t-beam's arms will run along beamAB (the floor)
groove(space, beamAB, ballL)
groove(space, beamAB, ballR)

groove(space, tb, ballP, (0,-20), (0, -2*a))
   # ballP runs along a groove on the trunk of the t-beam

# beamF0's groove holds ballV *and* ballUp
ballF = ball(space, "F", coordF)
beamF0 = beam(space, ballF, pt0)
groove(space, beamF0, ballV)  # one of the coupler balls
groove(space, beamF0, ballUp) # the top of the inverted t-beam

ballP.velocity = (500, 0)   # move right
animate(screen, space, ballP)
