
# archSpiralL.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Archimedean_spiral
'''
  p.210, Yates, "Curves and their Properties"
    - Carpenter's Square
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

LIN_VEL = 4
ANG_VEL = -0.25*math.pi  # ccw

def limit_velocity(body, gravity, damping, dt):
  # keep velocities near to their initial values
  pymunk.Body.update_velocity(body, gravity, damping, dt)
  vMag = body.velocity.length  # for ball B
  tangentBeam.angular_velocity = ANG_VEL
  # print(f"B Linear: {vMag:.2f}, 0A Angular: {tangentBeam.angular_velocity:.2f}")
  if vMag > LIN_VEL:
    scale = LIN_VEL / vMag
    body.velocity = body.velocity * scale



screen = scrInit("Archimedes Spiral Using Carpenter's Square")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
r = 50  # radius of wheel
coordA = coord0 + Vec2d(0, -r)

pt0 = staticBall(space, "0", coord0)
ballA = ball(space, "A", coordA)
ballB = ball(space, "B", coordA)
ballC = ball(space, "C", coord0, color=RED)

tangentBeam, tBot, tLeft, tRight = \
      tBeam(space, ballA, 20, r, name="")
  # return body and balls at three prongs of the 'T'
  # bottom, left, right
pin(space, pt0, tBot)  # fix trunk end to origin
  # so the tangent is to a circle

carpBeam = lBeam(space, ballB, -500, -r)
  # pt is the origin with arm to right and trunk up

# run arms of tangent along carpenter's square arm
groove(space, carpBeam, tLeft, (-500,0), (20,0))
groove(space, carpBeam, tRight, (-500,0), (20,0))
                  # extend groove off right end

pin(space, carpBeam, ballC, (0, r))

# set the linear and angular velocities
tangentBeam.angular_velocity = ANG_VEL
ballB.velocity = (LIN_VEL,0)  # move right
ballB.velocity_func = limit_velocity

animate(screen, space, ballC)
