
# chain.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
'''
  Example of how difficult it is to implement a
  string or chain in Pymunk. 

  The wheels must have collision detection enabled.
  This is the only example that needs this feature.

  Eventually, fiction slows the chain movement 
  almost to 0, and the drawn path becomes more
  chaotic.
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *


screen = scrInit("Chain", width=800)
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/4, scrHeight/2)
r = 2.8  # wheel radius 
a = 20   # length of a chain link
coordL = coord0
coordR = coord0 + Vec2d(20*a,0)
chainPts = [ (0,3), (2,3), (4,3), (6,3), (8,3), (10,3), (12,3), 
             (14,3), (16,3), (18,3), (20,3),
             (22,2.5), (23,1), (23,-1), (21.5,-2.5),
             (19,-3), (17,-3), (15,-3), (13,-3), (11,-3), (9,-3),
             (7,-3), (5,-3), (3,-3), (1,-3), (-1,-3),
             (-2.5,-2), (-3,-0.5), (-3,1.5), (-2, 2.7)
           ]

# generate balls for ends of the links
balls = []
for i in range( len(chainPts)):
  pt = chainPts[i]
  v = coord0 + Vec2d(pt[0]*a, pt[1]*a)
  if i == 0:
    balls.append( ball(space, "0", v,
                    color=RED))  # balls[0] is named
  else:
    balls.append( ball(space, "", v))

# generate the links as small beams
beams = []
for i in range( len(balls)-1):
  beams.append( beam(space, balls[i], balls[i+1]))

# link the last back to the first to form a chain
beams.append( beam(space, balls[len(balls)-1], balls[0]))

# two wheels, both with collision detection enabled 
# so the chain can rest on them

pt1 = staticBall(space, "", coordL)
wheel1 = ball(space, "W1", coordL, radius=r*a, solid=True)
pin(space, pt1, wheel1)

pt2 = staticBall(space, "", coordR)
wheel2 = ball(space, "W2", coordR, radius=r*a, solid=True)
pin(space, pt2, wheel2)

geared(space, wheel1, wheel2)

# set initial velocities
wheel1.angular_velocity = 0.4*math.pi  # clockwise
for i in range(8):   # move a few of the links 
 balls[i].velocity = (-300, 0)  # to left

animate(screen, space, balls[0])
