
# chebyshev.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Chebyshev_linkage
# https://en.wikipedia.org/wiki/Straight-line_mechanism
# also see chebyLambda.py

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Chebyshev linkage")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()
coord0 = Vec2d(scrWidth/2, scrHeight/2)

a = 50
coordA = coord0 + Vec2d(-2*a, 0)  
coordB = coord0 + Vec2d(2*a, 0) 
coordC = coord0 + Vec2d(-a, -4.9*a)
coordD = coord0 + Vec2d(0, -4.9*a)
coordE = coord0 + Vec2d(a, -4.9*a)

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ballC = ball(space, "C", coordC, color=GREEN)  
ballD = ball(space, "D", coordD, color=RED)  
ballE = ball(space, "E", coordE)  

beamAC = beam(space, ptA, ballC)
beamCE = beam(space, ballC, ballE)
beamBE = beam(space, ptB, ballE)
pin(space, beamCE, ballD, (coordE-coordC)/2)

ballD.velocity = (500, 0)  # move right

animate(screen, space, ballD, force=1000)
