
# cissoid.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Cissoid_of_Diocles
'''
Using Newton's construction (an l-beam).
Only generates the upper branch of the cissoid.
'''

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
import pygame
from pymunk.vec2d import Vec2d
from linkUtils import *


screen = scrInit("Cissoid")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight*3/4)
a = 100
coordB = coord0
coordP = coord0 + Vec2d(a, 0)
coordR = coord0 + Vec2d(2*a,0)
coordK = coordR + Vec2d(0, -450)
coordJ = coordR + Vec2d(0, 20)

pt0 = staticBall(space, "", coord0)
ptK = staticBall(space, "K", coordK)
ptJ = staticBall(space, "J", coordJ)
ballB = ball(space, "B", coord0)
ballS = ball(space, "S", coord0)
ballP = ball(space, "P", coordP, color=RED)
ballR = ball(space, "R", coordR)

beamKJ = beam(space, ptK, ptJ)
lbeam = lBeam(space, ballS, 2*a, 400)
pin(space, pt0, ballB)  
groove(space, lbeam, ballB, (0,0), (0,-400))
   # grove goes up the trunk of the l-beam

pin(space, lbeam, ballR, (2*a, 0))
groove(space, beamKJ, ballR)
pin(space, lbeam, ballP, (a, 0))

ballR.velocity = (0,-200)  # move up
ballS.velocity = (0,200)   # move down

animate(screen, space, ballP)
