
# conchoid.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Conchoid_(mathematics)
#    - includes animation
# select ballF or ballG for drawing
'''
For every line through O that intersects 'curve' AB at E the two points F and G on the line which are distance 'a' from E are on the conchoid. 
'''

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Conchoid")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)

a = 100
coordA = coord0 + Vec2d(-350, -0.5*a)
coordB = coord0 + Vec2d(350, -0.5*a)
coordC = coord0 + Vec2d(0, 300)
coordD = coord0 + Vec2d(0, -300)
coordE = coord0 + Vec2d(0, -0.5*a)  # intersection pt
coordF = coord0 + Vec2d(0, -1.5*a)  # pt at dist 'a' above
coordG = coord0 + Vec2d(0,  0.5*a)  # pt at dist 'a' below

pt0 = staticBall(space, "0", coord0)
ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ballC = ball(space, "C", coordC)
ballD = ball(space, "D", coordD)
ballE = ball(space, "E", coordE)
ballF = ball(space, "F", coordF, color=RED)
ballG = ball(space, "G", coordG, color=GREEN)

beamAB = beam(space, ptA, ptB)   # the 'curve' 
beamCD = beam(space, ballC, ballD)  # the line
beamFG = beam(space, ballF, ballG, color=MUSTARD)
  # a beam linking the two points F and G which are 
  # a distance 'a' from E

pin(space, beamCD, pt0, (0, -300))
groove(space, beamCD, ballE)
pin(space, beamFG, ballE, (0, a))
groove(space, beamCD, ballF)
groove(space, beamCD, ballG)
groove(space, beamAB, ballE)

ballD.velocity = (500, 0)  # move right
# use ballF or ballG to draw two sides of conchoid

animate(screen, space, ballF)  # ballF or ballG
