
# contraParBraced.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# "Geometric Folding Algorithms", sec 3.2.2.2, p.37
# based on contraPar.py

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *


screen = scrInit("Braced Contra-Parallelogram", width=900)
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()
coord0 = Vec2d(scrWidth/2, scrHeight*3/4)

a = 30
coordA = coord0 + Vec2d(-8*a, -4*a)
coordB = coord0 + Vec2d(2*a, -8*a)
coordC = coord0 + Vec2d(8*a, -4*a)
coordD = coord0 + Vec2d(-2*a, -8*a)

coordN = coord0 + Vec2d(-5*a, -6*a)
coordK = coord0 + Vec2d(-3*a, -6*a)
coordM = coord0 + Vec2d(3*a, -6*a)
coordL = coord0 + Vec2d(5*a, -6*a)


ballA = ball(space, "A", coordA)  # was static
ballB = ball(space, "B", coordB)    # was static
ballC = ball(space, "C", coordC)
ballD = ball(space, "D", coordD, color=RED)  

beamAB = beam(space, ballA, ballB)
beamAD = beam(space, ballA, ballD)
beamCD = beam(space, ballC, ballD)
beamCB = beam(space, ballC, ballB)

# additional pinned balls
pt0 = staticBall(space, "0", coord0)
ballN = ball(space, "N", coordN)
ballK = ball(space, "K", coordK)  
ballM = ball(space, "M", coordM)
ballL = ball(space, "L", coordL)  

pin(space, beamAB, ballK, (coordB-coordA)/2)
pin(space, beamAD, ballN, (coordD-coordA)/2)
pin(space, beamCD, ballM, (coordD-coordC)/2)
pin(space, beamCB, ballL, (coordB-coordC)/2)

# additional beams for bracing
beam0N = beam(space, pt0, ballN)
beam0K = beam(space, pt0, ballK)
beam0M = beam(space, pt0, ballM)
beam0L = beam(space, pt0, ballL)

# limit rotation around pt0
rotary(space, pt0, beam0N, 0,0)   # none

ballD.velocity = (0, 500)  # move down

animate(screen, space, ballD)
