
# crank.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Slider-crank_linkage

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Slider Crank")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
coordA = coord0 + Vec2d(-120,0)
coordB = coordA + Vec2d(0,-100)
coordD = coord0 + Vec2d(120,0)  # end of crank shaft
coordE = coord0 + Vec2d(300,0)

ptA = staticBall(space, "A", coordA)
ballB = ball(space, "B", coordB)
ptC = staticBall(space, "C", coord0)
ballD = ball(space, "D", coordD, color=RED)
ptE = staticBall(space, "E", coordE)

beamAB = beam(space, ptA, ballB)  # rotating arm
beamBD = beam(space, ballB, ballD)  # crank shaft
beamCE = beam(space, ptC, ptE)   # groove

groove(space, beamCE, ballD)

ballB.velocity = (-1000,0)  # move left
    # -5000 or more is too fast initially

animate(screen, space, ballD)
