
# cycloid.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Cycloid
'''
  Also see cycloidBeam.py which replaces the wheel used here with a rotating beam
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Cycloid", width=1400, height=300)
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
coordA = coord0 - Vec2d(650,0)
coordB = coord0 + Vec2d(650,0)
r = 50  # radius of wheel
drawPos = 2*r    # try 2*r, r/2
coordE = coordA + Vec2d(drawPos, 0) 

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)

wheel = ball(space, "W", coordA, radius=r)
beamAB = beam(space, ptA, ptB)
groove(space, beamAB, wheel)

ballE = ball(space, "E", coordE, color=RED)
ballE.mass = 0.00001  # so will not affect wheel when pinned
pin(space, wheel, ballE, (drawPos, 0))  
# right edge of wheel; will be off the edge if drawPos > r

wheel.velocity = (100,0)  # move right
wheel.angular_velocity = 0.5*math.pi  # turns clockwise

animate(screen, space, ballE)
