
# cycloidBeam.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Cycloid
'''
  Compare to cycloid.py;
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Cycloid using a beam", width=1400, height=300)
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
coordA = coord0 - Vec2d(650,0)
coordB = coord0 + Vec2d(650,0)
r = 50  # radius of wheel
coordE = coordA + Vec2d(r,0)   # right ; try 2*r, r/2

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ballD = ball(space, "D", coordA)
ballE = ball(space, "E", coordE, color=RED)
ballE.mass = 0.00001  # so will not affect beam when pinned

beamDE = beam(space, ballD, ballE)
beamAB = beam(space, ptA, ptB)
groove(space, beamAB, ballD)

ballD.velocity = (100,0)  # move right
beamDE.angular_velocity = 0.65*math.pi  # This is probably due to the difference momentum between the wheel and a rotating beam. In the former case, the wheel is assigned both a linear and angular velocity. For the beam, the linear velocity iis assigned to the center point, ball "D", and the angular velocity to the beam DE. turns cw

animate(screen, space, ballE)
