
# ellipseCT.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://www.sineofthetimes.org/drawing-ellipses-with-a-congruent-triangle-construction/
# https://www.geogebra.org/m/SCcGqsSj
'''
  The ellipse is unstable in the two regions when 
  the AC and BF beams used by E are nearly parallel
'''

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
import pygame
from pymunk.vec2d import Vec2d
from linkUtils import *

title = "Ellipse (Congruent Triangle)"
screen = scrInit(title)
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
a = 70
coordA = coord0 + Vec2d(-a,0)
coordB = coord0 + Vec2d(a,0)
coordE = coordA + Vec2d(-a,0)
coordF = coordB + Vec2d(-4*a,0)
coordC = coordA + Vec2d(-4*a,0)

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ballC = ball(space, "C", coordC)
sliderE = ball(space, "E", coordE, color=RED)
ballF = ball(space, "F", coordF)

beamFB = beam(space, ballF, ptB)
beamCA = beam(space, ballC, ptA)
beamFC = beam(space, ballF, ballC)

groove(space, beamFB, sliderE)
groove(space, beamCA, sliderE)

ballC.velocity = (0, 500)  # move down
animate(screen, space, sliderE)
