
# hartAFrame.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Hart%27s_inversors
# https://en.wikipedia.org/wiki/Straight-line_mechanism
'''
  If E drops below both D and C then the line
  can curve into two leaves. This is more likely 
  to happen if the two rotary restrictions are
  commented out.
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *


screen = scrInit("Hart's A-frame")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight*3/5)

h = 4*math.sqrt(2) * 50
base = 2 * 50
coordA = coord0 + Vec2d(-base, 0)  
coordB = coord0 + Vec2d(base, 0)
coordF = coord0 + Vec2d(-base/2, -h/2)
coordG = coord0 + Vec2d(base/2, -h/2)
coordC = coord0 + Vec2d(-base/3, -h*2/3)
coordD = coord0 + Vec2d(base/3, -h*2/3)
coordE = coord0 + Vec2d(0, -h)

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ballF = ball(space, "F", coordF)  
ballG = ball(space, "G", coordG)  
ballC = ball(space, "C", coordC, color=GREEN)  
ballD = ball(space, "D", coordD)  
ballE = ball(space, "E", coordE, color=RED)  

beamAC = beam(space, ptA, ballC, color=MUSTARD)
pin(space, beamAC, ballF, (coordC-coordA)*0.75)

beamBD = beam(space, ptB, ballD, color=MUSTARD)
pin(space, beamBD, ballG, (coordD-coordB)*0.75)

beam(space, ballF, ballG)
beam(space, ballC, ballE)
beam(space, ballD, ballE)

# (mostly) restrict curve to the straight line part
rotary(space, ptA, beamAC, -30, 140)
rotary(space, ptB, beamBD, -140, 30)

ballC.velocity = (-500, 0)  # move left (or could be right)

animate(screen, space, ballE)
