
# hyperbolaFrame.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
#  Linkage for drawing hyperbola 1; thang010146
# https://www.youtube.com/watch?v=iUJmd0_7sGw

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *


def frame(space, pt, width, height, color=LIGHTBLUE):
  # pt is top-left corner of the width x height frame
  rBody = pymunk.Body()
  rBody.position = pt.position
  bottom = pymunk.Segment(rBody, (0,0), (width,0), 5)
  top = pymunk.Segment(rBody, (0,height), (width,height), 5)
  left = pymunk.Segment(rBody, (0,0), (0,height), 5)
  right = pymunk.Segment(rBody, (width,0), (width,height), 5)
  for seg in [bottom, top, left, right]:
    seg.color = color + (0,)
    seg.mass = 1
    seg.elasticity = 0; seg.friction = 1
    seg.filter = SHP_FILT
  joint = pymunk.PinJoint(rBody, pt, (0, 0), (0, 0))
  joint.collide_bodies=False
  space.add(bottom, top, left, right, rBody, joint)
  return rBody


screen = scrInit("Hyperbola frame linkage")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
d =100 * 2
a = 80 * 2
b = 20 * 2
coordS = coord0 + Vec2d(-d, 6*b)
coordA = coord0 + Vec2d(-d, -a)
coordT = coord0 + Vec2d(d, a)
coordF = coord0 + Vec2d(-d-a, 0)
coordB = coord0 + Vec2d(-d, 0)
coordG = coord0 + Vec2d(d*3/2, 0)

ptF = staticBall(space, "F", coordF)
ptG = staticBall(space, "G", coordG)
ballS = ball(space, "S", coordS)
ballA = ball(space, "A", coordA)
ballK = ball(space, "K", coord0, color=RED)
ballT = ball(space, "T", coordT)
ballB = ball(space, "B", coordB)
ballC = ball(space, "C", coord0)
ballV = ball(space, "V", coord0) # at origin

beamAT = beam(space, ballA, ballT, color=LIGHTGREEN)
frame = frame(space, ballS, d, -a-7*b)
beamFG = beam(space, ptF, ptG, color=MUSTARD)

groove(space, beamAT, ballK)

pin(space, frame, ballA, (0, -a-6*b))

groove(space, frame, ballK, (d,-a-7*b), (d, 0))
    # groove down right side of frame

groove(space, beamFG, ballB)
groove(space, beamFG, ballC)

pin(space, frame, ballB, (0, -6*b))
pin(space, frame, ballC, (d, -6*b))
 
pin(space, beamFG, ballV, coord0-coordF)
groove(space, beamAT, ballV)


ballB.velocity = (-1000, 0)  # move left
animate(screen, space, ballK, force=1000)

