
# hyperbolaX.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
#  Hyperbola drawing linkage; thang010146
# https://www.youtube.com/watch?v=rQB6abVhLo4
'''
  The OB arm is over-stretched at the two extremes
  of the hyperbola
'''

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
import pygame
from pymunk.vec2d import Vec2d
from linkUtils import *


screen = scrInit("Hyperbola X Shape")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
coordP = coord0 + Vec2d(100, 0)  # also used for B
coordC = coord0 - Vec2d(100, 0)
coordD = coord0 + Vec2d(300, 0)
coordG = coord0 + Vec2d(50, 0)

pt0 = staticBall(space, "0", coord0)
ptC = staticBall(space, "C", coordC)
ptD = staticBall(space, "D", coordD)
ballB = ball(space, "B", coordP)  # same as P
sliderP = ball(space, "P", coordP, color=RED)
ballG = ball(space, "G", coordG)
ballH = ball(space, "H", coordD)

beam0B = beam(space, pt0, ballB, color=PINK)
xb = xBeam(space, ballB, 200, 200)  
                   # arm & trunk lengths
beamCH =  beam(space, ptC, ballH, color=LIGHTGREEN)
pin(space, beamCH, ballG, (150, 0))

# sliderP move along the trunk of X
groove(space, xb, sliderP, (0,-200), (0, 200))

groove(space, beamCH, sliderP)

# ballG moves along left arm of X
groove(space, xb, ballG, (0,0), (-100,0))

# end of right arm is pinned at D
pin(space, xb, ptD, (200,0))

sliderP.velocity = (0, -1500)  # move up fast to stretch OB
animate(screen, space, sliderP)
