
# hypocycloid.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Hypocycloid
'''
The wheel is at the end of a beam that spins
due to the wheel's initial velocity going down.
See cardioid.py for the epicycloid when the velocity
is initially upwards.
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Hypercycloid")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
r = 50
coordA = coord0 + Vec2d(3*r,0)
coordB = coordA + Vec2d(r,0)

pt0 = staticBall(space, "0", coord0)
ballA = ball(space, "A", coordA)
ballB = ball(space, "B", coordB, color=RED)
ballB.mass = 0.00001

beamD = beam(space, pt0, ballA, color=MUSTARD)
wheel = ball(space, "", coordA, radius=r)

pin(space, wheel, ballA)
pin(space, wheel, ballB, (r, 0))  # bottom of wheel

wheel.velocity = (0, -100)   # move up, so beam turn ccw
wheel.angular_velocity = 0.27*math.pi  # clockwise
                # creates an astroid (almost)
                # try 0.5, 1, 5

animate(screen, space, ballB)
