
# limacon.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# Pedal curves: calculus in motion; Zenzicubic
# https://www.youtube.com/watch?v=ejtqjxGvhL0

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Pedal curve for limacon")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
r = 50  # radius of wheel
coordA = coord0 + Vec2d(0, -r)
coordP = coord0 + Vec2d(0, -2*r)  # pedal point

pt0 = staticBall(space, "0", coord0)
ptP = staticBall(space, "P", coordP)
ballA = ball(space, "A", coordA)
ballB = ball(space, "B", coordA, color=RED)

tangentBeam, ballBot, _, _ = \
      tBeam(space, ballA, 300, r, name=" ")
  # return body and balls at three prongs of the 'T'
  # bottom, left, right
pin(space, pt0, ballBot)  # fix trunk end to origin
  # so the tangent is to a circle


xb = xBeam(space, ballB, 50, 300)
xleft = ball(space, "", coordA + Vec2d(-50,0))
xright = ball(space, "", coordA + Vec2d(50,0))
pin(space, xb, xleft, (-50, 0))
pin(space, xb, xright, (50, 0))

# run arms of xbeam in tangent groove
groove(space, tangentBeam, xleft, (-300,0), (300,0))
groove(space, tangentBeam, xright, (-300,0), (300,0))

# create groove up trunk of x-beam for sliding over ptP
groove(space, xb, ptP, (0, -300), (0, 300))


ballA.velocity = (1000,0)  # move right

animate(screen, space, ballB)
