
# lissajous.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Lissajous_curve
#  - includes an animation
'''
  Vary velCD and velVW to get diffferent curves
'''

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Lissajous")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()
coord0 = Vec2d(scrWidth/2, scrHeight/2)

a = 250  # coupler length
r  = 75  # wheel radius
offset = Vec2d(0, -r)  # offset used by wheels
coordP = coord0 + offset
ballP = ball(space, "P", coordP, color=RED)

# horizontal wheels pair
coordA = coord0 + Vec2d(-a, 0)
coordB = coord0 + Vec2d(a, 0)
ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
beamCD, ballC, ballD = coupler(space, ptA, ptB, r, offset)
   # beamCD can move left and right
groove(space, beamCD, ballP)

# vertical wheels pair
coordS = coord0 + Vec2d(0, a)
coordT = coord0 + Vec2d(0, -a)
ptS = staticBall(space, "S", coordS)
ptT = staticBall(space, "T", coordT)
beamST, ballV, ballW = coupler(space, ptS, ptT, r, offset)
   # beamST can move up and down
groove(space, beamST, ballP)

# wheels pairs move together
velCD = -100   # try -100
ballC.velocity = (velCD, 0)  # move up initially
ballD.velocity = (velCD, 0)

velVW = -200   # try -100
ballV.velocity = (velVW, 0)  # move left initially
ballW.velocity = (velVW, 0)

animate(screen, space, ballP)
