
# parabolaT.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# Parabola drawing linkage 1; thang010146
# https://www.youtube.com/watch?v=HBMYzPprNGQ

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *


title = "Parabola T Shape"
screen = scrInit(title)
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
coordE = coord0 + Vec2d(0, 150)
coordF = coordE - Vec2d(300, 0)
coordG = coordE + Vec2d(300, 0)
coordJ = coord0 - Vec2d(0, 300)

pt0 = staticBall(space, "0", coord0)
ptF = staticBall(space, "F", coordF)
ptG = staticBall(space, "G", coordG)
sliderD = ball(space, "D", coord0, color=RED)
sliderE = ball(space, "E", coordE)

# blue t-beam pointing down, linked to pt0
blueTB, _, _, _ = tBeam(space, pt0, 300, 310, color=LIGHTBLUE)  
    # supply arm & tip lengths; get back body, up, left, right

beamFG = beam(space, ptF, ptG)

# green t-beam facing up, linked to sliderE
greenTB, _, vLeft, vRight  = \
  tBeam(space, sliderE, 60, -350, name="1", color=LIGHTGREEN)


# slider along blue t-beam's arm
groove(space, blueTB, sliderD, (-290,0), (290,0))

# sliderE along blue t-beam's tip
groove(space, blueTB, sliderE, (0,20), (0,290))

groove(space, beamFG, sliderE)

# attach green T-beam's arms to groove along beamFG
groove(space, beamFG, vRight)
groove(space, beamFG, vLeft)

# attach sliderD to green t-beam
groove(space, greenTB, sliderD, (0,-350), (0,0))


sliderE.velocity = (1000, 0)   # move right

pts = animate(screen, space, sliderD)
plotPoints(pts, title)
