
# peaucellier.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Peaucellier%E2%80%93Lipkin_linkage
# https://en.wikipedia.org/wiki/Straight-line_mechanism

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Peaucellier–Lipkin linkage")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()
coord0 = Vec2d(scrWidth/3, scrHeight/2)

a = 150
bRoot = 100
coordA = coord0 + Vec2d(-a, 0)  
coordC = coord0 + Vec2d(a, 0)
coordD = coord0 + Vec2d(a+bRoot, -bRoot)
coordE = coord0 + Vec2d(a+2*bRoot, 0)
coordF = coord0 + Vec2d(a+bRoot, bRoot)

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coord0)
ballC = ball(space, "C", coordC, color=GREEN)  
ballD = ball(space, "D", coordD)  
ballE = ball(space, "E", coordE, color=RED)  
ballF = ball(space, "F", coordF)  

beamBC = beam(space, ptB, ballC)
rotary(space, ptB, beamBC, -45, 45)

beam(space, ptA, ballD)
beam(space, ptA, ballF)
beam(space, ballC, ballD)
beam(space, ballC, ballF)
beam(space, ballD, ballE)
beam(space, ballF, ballE)

ballC.velocity = (0, 500)  # move down
animate(screen, space, ballE)
