
# quadratrix.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Quadratrix_of_Hippias
# http://xahlee.info/SpecialPlaneCurves_dir/QuadratrixOfHippias_dir/quadratrixOfHippias.html
           # includes animation
'''
Uses a velocity function to keep three velocities
and two ball positions the same throughout. So moves
beyond simple joints. 

The velocity values are guesses.

The resulting curve is not quite a quadratrix
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *


LIN_VEL = (0, 80)   # move down
ANG_VEL = 0.14*math.pi  # cw
   # if this is too small (e.g. 0.1) then 
   # the curve returns to A


def velPos(body, gravity, damping, dt):
  # attached to ball S
  # keep velocities and positions in sync
  pymunk.Body.update_velocity(body, gravity, damping, dt)
  body.velocity = LIN_VEL   # velocity of S
  ballT.velocity = LIN_VEL
  beamAE.angular_velocity = ANG_VEL

  # keep y positions of S and T the same 
  _, y = body.position   # of S
  xT, _ = ballT.position
  ballT.position = (xT, y)


# --------------------------------------------
screen = scrInit("Quadratrix of Hippias")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
d = 300
coordA = coord0 + Vec2d(-d/2, 0)
coordB = coordA + Vec2d(0, -d)
coordC = coord0 + Vec2d(d/2,0)
coordD = coordC + Vec2d(0, -d)

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ptC = staticBall(space, "C", coordC)
ptD = staticBall(space, "D", coordD)
ballE = ball(space, "E", coordB)
ballP = ball(space, "P", coordB)
ballS = ball(space, "S", coordB)
ballT = ball(space, "T", coordD)

beamAB = beam(space, ptA, ptB)
groove(space, beamAB, ballS)

beamCD = beam(space, ptC, ptD)
groove(space, beamCD, ballT)

beamST = beam(space, ballS, ballT)
groove(space, beamST, ballP)

beamAE = beam(space, ptA, ballE)
groove(space, beamAE, ballP)
rotary(space, ptA, beamAE, 0, 90)

# set the linear and angular velocities
beamAE.angular_velocity = ANG_VEL
ballS.velocity = LIN_VEL  # move down
ballS.velocity_func = velPos
ballT.velocity = LIN_VEL  # same as S

animate(screen, space, ballP)
