
# roberts.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Roberts_linkage

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Robert's Linkage")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight*3/5)
coordA = coord0 + Vec2d(-200, 0)
coordB = coord0 + Vec2d(200, 0)

coordC = coordA + Vec2d(100, -240)
coordD = coordB + Vec2d(-100, -240)
coordE = coord0

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ballC = ball(space, "C", coordC)
ballD = ball(space, "D", coordD)
ballE = ball(space, "E", coordE, color=RED)

beamAC = beam(space, ptA, ballC)
beamBD = beam(space, ptB, ballD)
triCDE = triangle(space, ballC, ballD, ballE)

# restrict curve to the straight line part
rotary(space, ptA, beamAC, -30, 30)
rotary(space, ptB, beamBD, -30, 30)

ballE.velocity = (500, 0)   # move right
animate(screen, space, ballE)
