
# trainCoupler.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
'''
  Simple example of the coupler() function, which
  is used in agnesi.py and lissajous.py
'''

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

screen = scrInit("Train Coupler")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
a = 150  # length of couple
r  = 50  # wheel radius
offset = Vec2d(0, -r)  # offset is down from center
# horizontal wheel coords
coordA = coord0 + Vec2d(-a, 0)
coordB = coord0 + Vec2d(a, 0)
coordP = coord0 + offset

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ballP = ball(space, "P", coordP, color=RED)

beamST, ballV, _ = coupler(space, ptA, ptB, r, offset)
  # the linking beam and balls representing its two ends 

pin(space, beamST, ballP, (a, 0))

ballV.velocity = (-200, 0)  # move left

animate(screen, space, ballP)
