
# trammel.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Ellipsograph

import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *

title = "Trammel of Archimedes"
screen = scrInit(title)
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()
coord0 = Vec2d(scrWidth/2, scrHeight/2)

VERT = Vec2d(0, 200)
HORIZ = Vec2d(300, 0)
coordA = coord0 - HORIZ
coordB = coord0 + HORIZ
coordC = coord0 - VERT
coordD = coord0 + VERT
coordF = coord0
coordG = coordF + Vec2d(100, 0)
coordP = coordF + HORIZ
coordH = coordF - Vec2d(30, 0)

ptA = staticBall(space, "A", coordA)
ptB = staticBall(space, "B", coordB)
ptC = staticBall(space, "C", coordC)
ptD = staticBall(space, "D", coordD)
sliderG = ball(space, "G", coordG)
sliderF = ball(space, "F", coordF, color=GREEN)
ballH = ball(space, "H", coordH)
ballP = ball(space, "P", coordP, color=RED)

beamAB = beam(space, ptA, ptB)
beamCD = beam(space, ptC, ptD)
beamHP = beam(space, ballH, ballP)

groove(space, beamAB, sliderG)
groove(space, beamCD, sliderF)

# two balls pinned along the beam from H
pin(space, beamHP, sliderF, (30, 0))
pin(space, beamHP, sliderG, (130, 0))

sliderF.velocity = (0, 500)  # move down
pts = animate(screen, space, ballP)
plotPoints(pts, title)
