
# watts.py
# Andrew Davison, ad@coe.psu.ac.th, Feb. 2025
# https://en.wikipedia.org/wiki/Watt%27s_linkage
# https://en.wikipedia.org/wiki/Straight-line_mechanism

import math
import os
os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
from pymunk.vec2d import Vec2d
from linkUtils import *


screen = scrInit("Watt's Linkage")
scrWidth, scrHeight = screen.get_size()
space = pymunk.Space()

coord0 = Vec2d(scrWidth/2, scrHeight/2)
coordB = coord0 + Vec2d(90, -120)
coordC = coord0 + Vec2d(-90, 120)
coordA = coordB + Vec2d(-300, 0)
coordD = coordC + Vec2d(300, 0)

ptA = staticBall(space, "A", coordA)
ptD = staticBall(space, "D", coordD)
ballB = ball(space, "B", coordB)
ballC = ball(space, "C", coordC)
ballP = ball(space, "P", coord0, color=RED)

beamAB = beam(space, ptA, ballB)
beamBC = beam(space, ballB, ballC)
beamDC = beam(space, ptD, ballC)

pin(space, beamBC, ballP, (coordC-coordB)/2)

# restrict lemniscate to a 'vertical' line;
# remove to get a leminscate
rotary(space, ptA, beamAB, -45, 45)
rotary(space, ptD, beamDC, -45, 45)

ballP.velocity = (0, 500)  # move down

animate(screen, space, ballP)
